@@ -4,10 +4,10 @@ module Celluloid
     attr_accessor :pid
     attr_accessor :events, :triggering_event
 
-    def initialize(events, triggering_event=nil)
+    def initialize(events, triggering_event = nil)
       @events = events
       @triggering_event = triggering_event
-      @pid = $$
+      @pid = $PROCESS_ID
     end
 
     # Merge two incidents together. This may be useful if two incidents occur at the same time.
