@@ -1,5 +1,3 @@
-require 'thread'
-
 module Celluloid
   class MailboxDead < Celluloid::Error; end # you can't receive from the dead
   class MailboxShutdown < Celluloid::Error; end # raised if the mailbox can no longer be used
@@ -41,7 +39,11 @@ module Celluloid
         @condition.signal
         nil
       ensure
-        @mutex.unlock rescue nil
+        begin
+          @mutex.unlock
+        rescue
+          nil
+        end
       end
     end
 
@@ -54,30 +56,35 @@ module Celluloid
       begin
         raise MailboxDead, "attempted to receive from a dead mailbox" if @dead
 
+        message = nil
         Timers::Wait.for(timeout) do |remaining|
           message = next_message(&block)
 
-          break message if message
+          break if message
 
           @condition.wait(@mutex, remaining)
         end
       ensure
-        @mutex.unlock rescue nil
+        begin
+          @mutex.unlock
+        rescue
+          nil
+        end
       end
-      
-      return message
+
+      message
     end
 
     # Receive a letter from the mailbox. Guaranteed to return a message. If
-    # timeout is exceeded, raise a TimeoutError.
+    # timeout is exceeded, raise a TaskTimeout.
     def receive(timeout = nil, &block)
-      Timers::Wait.for(timeout) do |remaining|
-        if message = check(timeout, &block)
-          return message
-        end
+      message = nil
+      Timers::Wait.for(timeout) do |_remaining|
+        message = check(timeout, &block)
+        break if message
       end
-      
-      raise TimeoutError.new("receive timeout exceeded")
+      return message if message
+      raise TaskTimeout, "receive timeout exceeded"
     end
 
     # Shut down this mailbox and clean up its contents
@@ -91,7 +98,11 @@ module Celluloid
         @messages = []
         @dead = true
       ensure
-        @mutex.unlock rescue nil
+        begin
+          @mutex.unlock
+        rescue
+          nil
+        end
       end
 
       messages.each do |msg|
@@ -118,7 +129,7 @@ module Celluloid
 
     # Inspect the contents of the Mailbox
     def inspect
-      "#<#{self.class}:#{object_id.to_s(16)} @messages=[#{map { |m| m.inspect }.join(', ')}]>"
+      "#<#{self.class}:#{object_id.to_s(16)} @messages=[#{map(&:inspect).join(', ')}]>"
     end
 
     # Number of messages in the Mailbox
@@ -146,7 +157,10 @@ module Celluloid
     end
 
     def dead_letter(message)
-      Logger.debug "Discarded message (mailbox is dead): #{message}" if $CELLULOID_DEBUG
+      # !!! DO NOT INTRODUCE ADDITIONAL GLOBAL VARIABLES !!!
+      # rubocop:disable Style/GlobalVars
+      Internals::Logger.debug "Discarded message (mailbox is dead): #{message}" if $CELLULOID_DEBUG
+      # rubocop:enable Style/GlobalVars
     end
 
     def mailbox_full
