@@ -1,5 +1,3 @@
-require 'celluloid/fiber'
-
 module Celluloid
   class Thread < ::Thread
     def celluloid?
@@ -36,5 +34,10 @@ module Celluloid
     def call_chain_id
       self[:celluloid_chain_id]
     end
+
+    def <<(proc)
+      self[:celluloid_queue] << proc
+      self
+    end
   end
 end
